Type

Enum Type 

pub enum Type {
Show 23 variants Bool, S8, U8, S16, U16, S32, U32, S64, U64, Float32, Float64, Char, String, List(List), Record(Record), Tuple(Tuple), Variant(Variant), Enum(Enum), Option(OptionType), Result(ResultType), Flags(Flags), Own(ResourceType), Borrow(ResourceType),
}
Available on crate feature component-model only.
Represents a component model interface type

Variants



Bool



S8



U8



S16



U16



S32



U32



S64



U64



Float32



Float64



Char



String



List(List)



Record(Record)



Tuple(Tuple)



Variant(Variant)



Enum(Enum)



Option(OptionType)



Result(ResultType)



Flags(Flags)



Own(ResourceType)



Borrow(ResourceType)

Implementations

Source

impl Type

pub fn unwrap_list(&self) -> &List

Available on crate feature runtime only.

Retrieve the inner List of a Type::List.

Panics

This will panic if self is not a Type::List.

pub fn unwrap_record(&self) -> &Record

Available on crate feature runtime only.

Retrieve the inner Record of a Type::Record.

Panics

This will panic if self is not a Type::Record.

pub fn unwrap_tuple(&self) -> &Tuple

Available on crate feature runtime only.

Retrieve the inner Tuple of a Type::Tuple.

Panics

This will panic if self is not a Type::Tuple.

pub fn unwrap_variant(&self) -> &Variant

Available on crate feature runtime only.

Retrieve the inner Variant of a Type::Variant.

Panics

This will panic if self is not a Type::Variant.

pub fn unwrap_enum(&self) -> &Enum

Available on crate feature runtime only.

Retrieve the inner Enum of a Type::Enum.

Panics

This will panic if self is not a Type::Enum.

pub fn unwrap_option(&self) -> &OptionType

Available on crate feature runtime only.

Retrieve the inner OptionType of a Type::Option.

Panics

This will panic if self is not a Type::Option.

pub fn unwrap_result(&self) -> &ResultType

Available on crate feature runtime only.

Retrieve the inner ResultType of a Type::Result.

Panics

This will panic if self is not a Type::Result.

pub fn unwrap_flags(&self) -> &Flags

Available on crate feature runtime only.

Retrieve the inner Flags of a Type::Flags.

Panics

This will panic if self is not a Type::Flags.

pub fn unwrap_own(&self) -> &ResourceType

Available on crate feature runtime only.

Retrieve the inner ResourceType of a Type::Own.

Panics

This will panic if self is not a Type::Own.

pub fn unwrap_borrow(&self) -> &ResourceType

Available on crate feature runtime only.

Retrieve the inner ResourceType of a Type::Borrow.

Panics

This will panic if self is not a Type::Borrow.