pub struct Component(/* private fields */);Available on crate feature
component-model only.Expand description
Component type
Implementations
Sourceimpl Component
impl Component
Sourcepub fn get_import(&self, engine: &Engine, name: &str) -> Option<ComponentItem>
Available on crate feature runtime only.
pub fn get_import(&self, engine: &Engine, name: &str) -> Option<ComponentItem>
runtime only.Returns import associated with name, if such exists in the component
Sourcepub fn imports<'a>(
&'a self,
engine: &'a Engine,
) -> impl ExactSizeIterator<Item = (&str, ComponentItem)> + 'a
Available on crate feature runtime only.
pub fn imports<'a>( &'a self, engine: &'a Engine, ) -> impl ExactSizeIterator<Item = (&str, ComponentItem)> + 'a
runtime only.Iterates over imports of the component
Sourcepub fn get_export(&self, engine: &Engine, name: &str) -> Option<ComponentItem>
Available on crate feature runtime only.
pub fn get_export(&self, engine: &Engine, name: &str) -> Option<ComponentItem>
runtime only.Returns export associated with name, if such exists in the component
Sourcepub fn exports<'a>(
&'a self,
engine: &'a Engine,
) -> impl ExactSizeIterator<Item = (&str, ComponentItem)> + 'a
Available on crate feature runtime only.
pub fn exports<'a>( &'a self, engine: &'a Engine, ) -> impl ExactSizeIterator<Item = (&str, ComponentItem)> + 'a
runtime only.Iterates over exports of the component