GlobalType

Struct GlobalType 

pub struct GlobalType { /* private fields */ }
A WebAssembly global descriptor.

This type describes an instance of a global in a WebAssembly module. Globals are local to an Instance and are either immutable or mutable.

Implementations

Source

impl GlobalType

pub fn new(content: ValType, mutability: Mutability) -> GlobalType

Available on crate feature runtime only.

Creates a new global descriptor of the specified content type and whether or not it’s mutable.

pub fn content(&self) -> &ValType

Available on crate feature runtime only.

Returns the value type of this global descriptor.

pub fn mutability(&self) -> Mutability

Available on crate feature runtime only.

Returns whether or not this global is mutable.