pub struct StoreContextMut<'a, T>(/* private fields */);Expand description
A temporary handle to a &mut Store<T>.
This type is suitable for AsContextMut or AsContext trait bounds on
methods if desired. For more information, see Store.
Implementations
Sourceimpl<'a, T> StoreContextMut<'a, T>
impl<'a, T> StoreContextMut<'a, T>
Sourcepub fn data(&self) -> &T
Available on crate feature runtime only.
pub fn data(&self) -> &T
runtime only.Access the underlying data owned by this Store.
Same as Store::data.
Sourcepub fn data_mut(&mut self) -> &mut T
Available on crate feature runtime only.
pub fn data_mut(&mut self) -> &mut T
runtime only.Access the underlying data owned by this Store.
Same as Store::data_mut.
Sourcepub fn engine(&self) -> &Engine
Available on crate feature runtime only.
pub fn engine(&self) -> &Engine
runtime only.Returns the underlying Engine this store is connected to.
Sourcepub fn gc(&mut self)
Available on crate features runtime and gc only.
pub fn gc(&mut self)
runtime and gc only.Perform garbage collection of ExternRefs.
Same as Store::gc.
This method is only available when the gc Cargo feature is enabled.
Sourcepub async fn gc_async(&mut self)where
T: Send,
Available on crate features async and gc and runtime only.
pub async fn gc_async(&mut self)where
T: Send,
async and gc and runtime only.Perform garbage collection of ExternRefs.
Same as Store::gc.
This method is only available when the gc Cargo feature is enabled.
Sourcepub fn get_fuel(&self) -> Result<u64>
Available on crate feature runtime only.
pub fn get_fuel(&self) -> Result<u64>
runtime only.Returns remaining fuel in this store.
For more information see Store::get_fuel
Sourcepub fn set_fuel(&mut self, fuel: u64) -> Result<()>
Available on crate feature runtime only.
pub fn set_fuel(&mut self, fuel: u64) -> Result<()>
runtime only.Set the amount of fuel in this store.
For more information see Store::set_fuel
Sourcepub fn fuel_async_yield_interval(&mut self, interval: Option<u64>) -> Result<()>
Available on crate feature runtime only.
pub fn fuel_async_yield_interval(&mut self, interval: Option<u64>) -> Result<()>
runtime only.Configures this Store to periodically yield while executing futures.
For more information see Store::fuel_async_yield_interval
Sourcepub fn set_epoch_deadline(&mut self, ticks_beyond_current: u64)
Available on crate feature runtime only.
pub fn set_epoch_deadline(&mut self, ticks_beyond_current: u64)
runtime only.Sets the epoch deadline to a certain number of ticks in the future.
For more information see Store::set_epoch_deadline.
Sourcepub fn epoch_deadline_trap(&mut self)
Available on crate feature runtime only.
pub fn epoch_deadline_trap(&mut self)
runtime only.Configures epoch-deadline expiration to trap.
For more information see Store::epoch_deadline_trap.
Sourcepub fn epoch_deadline_async_yield_and_update(&mut self, delta: u64)
Available on crate features runtime and async only.
pub fn epoch_deadline_async_yield_and_update(&mut self, delta: u64)
runtime and async only.Configures epoch-deadline expiration to yield to the async caller and the update the deadline.
For more information see
Store::epoch_deadline_async_yield_and_update.