pub struct TableType { /* private fields */ }Expand description
A descriptor for a table in a WebAssembly module.
Tables are contiguous chunks of a specific element, typically a funcref or
an externref. The most common use for tables is a function table through
which call_indirect can invoke other functions.
Implementations
Sourceimpl TableType
impl TableType
Sourcepub fn new(element: RefType, min: u32, max: Option<u32>) -> TableType
Available on crate feature runtime only.
pub fn new(element: RefType, min: u32, max: Option<u32>) -> TableType
runtime only.Creates a new table descriptor which will contain the specified
element and have the limits applied to its length.
Sourcepub fn element(&self) -> &RefType
Available on crate feature runtime only.
pub fn element(&self) -> &RefType
runtime only.Returns the element value type of this table.